/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.fetcher.impl;

import java.io.File;
import java.util.Dictionary;

import org.osgi.service.cm.ConfigurationException;
import org.osgi.service.cm.ManagedService;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.plan.fetcher.api.Constants;
import org.ow2.util.plan.fetcher.api.IResourceFetcherFactory;
import org.ow2.util.plan.fetcher.api.IResourceFetcherFactoryManager;

/**
 * @author Mickaël LEDUQUE
 */
public class LocalRepositoriesBaseDirConfiguration implements ManagedService {

    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(FetcherActivator.class);

    /**
     * The local repositories base directory.
     */
    private File localRepositoriesBaseDir = null;

    /**
     * The related resource fetcher factory manager.
     */
    private IResourceFetcherFactoryManager resourceFetcherFactoryManager;

    /**
     * Creates a LocalRepositoriesBaseDirConfiguration with the given resource fetcher
     * factory manager.
     * @param manager the resource fetcher factory manager.
     */
    public LocalRepositoriesBaseDirConfiguration(IResourceFetcherFactoryManager manager) {
        this.resourceFetcherFactoryManager = manager;
    }


    /**
     * {@inheritDoc}
     */
    @SuppressWarnings("unchecked")
    public void updated(Dictionary properties) throws ConfigurationException {
        if (properties != null) {
            String path = (String) properties.get(Constants.LOCAL_REPOSITORIES_BASE_DIR);
            logger.debug("Local repositories base directory property updated: '{0}", path);
            if (path == null) {
                throw new ConfigurationException(Constants.LOCAL_REPOSITORIES_BASE_DIR, "Path to the local repositories is null.");
            }
            File localDir = new File(path);

            if (!localDir.exists()) {
                localDir.mkdirs();
            }

            this.localRepositoriesBaseDir = localDir;

            for (IResourceFetcherFactory factory : this.resourceFetcherFactoryManager) {
                factory.setLocalRepositoriesBaseDir(this.localRepositoriesBaseDir);
            }
        }
    }

}
