/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.fetcher.maven2;

import java.io.File;

import org.ow2.util.plan.bindings.deploymentplan.maven2.Maven2Deployment;
import org.ow2.util.plan.bindings.repository.Repository;
import org.ow2.util.plan.bindings.repository.RepositoryKind;
import org.ow2.util.plan.fetcher.impl.maven2.Maven2ResourceFetcher;
import org.ow2.util.plan.fetcher.impl.maven2.Maven2ResourceFetcherFactory;
import org.ow2.util.plan.repository.api.IRepositoryManager;
import org.ow2.util.plan.repository.impl.DefaultRepositoryManager;
import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * Test for the Maven 2 resource fetcher.
 * @author Mickaël LEDUQUE
 */
public class Maven2FetcherTest {

    /**
     * The maven 2 fetcher used in the tests.
     */
    private Maven2ResourceFetcherFactory mavenFetcherFactory = new Maven2ResourceFetcherFactory();

    /**
     * The build working directory
     */
    private static final String USER_DIR = System.getProperty("user.dir");

    /**
     * The relative path to the test directory
     */
    private String TEST_DIR;

    /**
     * The groupId for the artifact fetching test.
     */
    private static final String TEST_GROUPID = "org.ow2";

    /**
     * The artifactId for the artifact fetching test.
     */
    private static final String TEST_ARTIFACTID = "ow2";

    /**
     * The version for the artifact fetching test.
     */
    private static final String TEST_VERSION = "1.0";

    /**
     * The type for the artifact fetching test.
     */
    private static final String TEST_TYPE = "pom";


    @Test
    public void prepareFactory() throws Exception {
        /* Set up the test location */
        StringBuilder sb = new StringBuilder();
        sb.append(File.separatorChar);
        sb.append("target");
        sb.append(File.separatorChar);
        sb.append("test-classes");
        sb.append(File.separatorChar);
        sb.append("repository");
        sb.append(File.separatorChar);
        TEST_DIR = sb.toString();

        File localRepositoriesBaseDir = new File(USER_DIR + TEST_DIR);
        if (localRepositoriesBaseDir.exists()) {
            localRepositoriesBaseDir.delete();
        }
        localRepositoriesBaseDir.mkdir();

        mavenFetcherFactory.setLocalRepositoriesBaseDir(localRepositoriesBaseDir);
    }

    //@Test(dependsOnMethods={"prepareFactory"})
    public void testWithNonLocalArtifact() throws Exception {
        /* Set up the repository */
        IRepositoryManager repositoryManager = DefaultRepositoryManager.getInstance();
        Repository repository = new Repository();
        repository.setId("ow2");
        repository.setUrl("http://maven.ow2.org/maven2/");
        repository.setType(RepositoryKind.MAVEN_2);
        repositoryManager.addRepository(repository);
        mavenFetcherFactory.setRepositoryManager(repositoryManager);

        /* Create the maven 2 deployment */
        Maven2Deployment deployment = new Maven2Deployment();
        deployment.setId("ow2 artifact");
        deployment.setGroupId(TEST_GROUPID);
        deployment.setArtifactId(TEST_ARTIFACTID);
        deployment.setVersion(TEST_VERSION);
        deployment.setType(TEST_TYPE);

        /* Resolve the artifact */
        Maven2ResourceFetcher mavenFetcher = (Maven2ResourceFetcher)mavenFetcherFactory.getResourceFetcher(deployment);
        mavenFetcher.resolve();
        File result = mavenFetcher.getResource();
        Assert.assertNotNull(result);

        /* Check there is a local file for the artifact */
        Assert.assertTrue(result.exists());

        /* Create a File object for the expected result (location) */
        StringBuilder sb = new StringBuilder(USER_DIR);
        sb.append(TEST_DIR);
        sb.append(TEST_GROUPID.replace('.', File.separatorChar));
        sb.append(File.separatorChar);
        sb.append(TEST_ARTIFACTID);
        sb.append(File.separatorChar);
        sb.append(TEST_VERSION);
        sb.append(File.separatorChar);
        sb.append(TEST_ARTIFACTID);
        sb.append('-');
        sb.append(TEST_VERSION);
        sb.append('.');
        sb.append(TEST_TYPE);

        File expected = new File(sb.toString());

        /* Check the file is at the good place */
        Assert.assertEquals(result, expected);
    }
}
