/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.bindings.activator;

import java.util.Dictionary;
import java.util.Hashtable;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.plan.bindings.SchemaConstants;
import org.ow2.util.plan.bindings.schemastream.ISchemaStreamFactory;
import org.ow2.util.plan.bindings.schemastream.SchemaStreamFactoryImpl;

/**
 * Activator for the schema bundle.
 * @author Mickaël LEDUQUE
 */
public class SchemaActivator implements BundleActivator {

    /**
     * The registration object for the SchemaStreamFactory.
     */
    private ServiceRegistration<ISchemaStreamFactory> schemaStreamFactoryRegistration = null;

    /**
     * {@inheritDoc}
     */
    public void start(BundleContext context) throws Exception {
        ISchemaStreamFactory schemaStreamFactory = new SchemaStreamFactoryImpl();
        Dictionary<String, String> props = new Hashtable<String, String>();
        props.put(SchemaConstants.SCHEMA_NAMESPACE_PROPERTY, SchemaConstants.DEPLOYMENT_PLAN_NAMESPACE);
        this.schemaStreamFactoryRegistration = context.registerService(
                ISchemaStreamFactory.class, schemaStreamFactory, props);

    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext context) throws Exception {
        this.schemaStreamFactoryRegistration.unregister();
    }

}
